Learn R Programming

lpacf (version 1.0.1)

lpacf-package: Compute localized partial autocorrelation for locally stationary wavelet time series.

Description

This package computes a localized partial autocorrelation of a time series assuming a locally stationary wavelet model.

Arguments

Author

Rebecca Killick, Marina Knight, Guy Nason and Matt Nunes

Maintainer: Rebecca Killick <r.killick@lancs.ac.uk>

Details

Package:lpacf
Type:Package
Version:1.0.1
Date:2023-05-12
License:GPL-2

The lpacf function computes the localized partial autocorrelation of a locally stationary time series. The resultant object can be printed using print.lpacf or plotted by plot.lpacf.

References

Killick, R., Knight, M. I., Nason, G.P. and Eckley, I. A. (2020) The local partial autocorrelation function and some applications. Electron. J. Statist. 14 (2), 3268-3314. DOI: 10.1214/20-EJS1748.

See Also

lpacf

Examples

Run this code
#
# See examples in each of the functions' help pages linked above.
#

Run the code above in your browser using DataLab