summary.lpacf: Print out summary information about a lpacf object.
Description
Print out summary information about a lpacf object.
Usage
# S3 method for lpacf
summary(object, ...)
Value
None
Arguments
object
The lpacf object you want to print out summary info for.
...
Other arguments
Author
Guy Nason
Details
Prints out number of times that we have localized partial
autocorrelation for and the number of lags computed. The localized
partial autocorrelation is computed at a number of time points that
might not be identical to the times in the original series, this
function prints out the min and max of the range of times and
an indicator of whether the whole series' localized pacf was computed.
The bandwidth associated with spectral smoothing is printed and
a note made of whether it was computed automatically or supplied
as an earlier argument.
References
Killick, R., Knight, M. I., Nason, G.P. and Eckley, I. A. (2020) The local partial autocorrelation function and some applications. Electron. J. Statist.14 (2), 3268-3314. DOI: 10.1214/20-EJS1748.